@@ -164,7 +164,7 @@ static int __init snd_card_ad1816a_resources(int dev,
 					     snd_card_t *card)
 {
 	int error;
-	static int no_alternatives[] = {-1};
+	static long no_alternatives[] = {-1};
 
 	if (snd_register_ioport(card, snd_mpu_port[dev], 2,
 			DRIVER_NAME" - MPU-401", NULL) < 0)
