@@ -179,7 +179,7 @@ static int __init snd_card_als100_resources(int dev,
 					    snd_card_t *card)
 {
 	int error;
-	static int no_alternatives[] = {-1};
+	static long no_alternatives[] = {-1};
 
 	if (snd_register_ioport(card, snd_mpu_port[dev], 2,
 			DRIVER_NAME" - MPU-401", NULL) < 0)
@@ -380,7 +380,7 @@ static int __init snd_card_als100_probe(int dev, struct snd_card_als100 *acard)
 
 	strcpy(card->abbreviation, "ALS100");
 	strcpy(card->shortname, "Avance Logic ALS100");
-	sprintf(card->longname, "%s soundcard, %s at 0x%x, irq %i, dma %i&%i",
+	sprintf(card->longname, "%s soundcard, %s at 0x%lx, irq %li, dma %li&%li",
 		card->shortname, codec->name, codec->port,
 		acard->irqptr->irq, acard->dma8ptr->dma, acard->dma16ptr->dma);
 	if (!snd_card_register(card)) {
