@@ -182,7 +182,7 @@ static int __init snd_card_azt2320_resources(int dev,
 					     snd_card_t *card)
 {
 	int error;
-	static int no_alternatives[] = {-1};
+	static long no_alternatives[] = {-1};
 
 	if (snd_register_ioport(card, snd_mpu_port[dev], 2,
 			DRIVER_NAME" - MPU-401", NULL) < 0)
@@ -402,7 +402,7 @@ static int __init snd_card_azt2320_probe(int dev, struct snd_card_azt2320 *acard
 
 	strcpy(card->abbreviation, "AZT2320");
 	strcpy(card->shortname, "Aztech AZT2320");
-	sprintf(card->longname, "%s soundcard, WSS at 0x%x, irq %i, dma %i&%i",
+	sprintf(card->longname, "%s soundcard, WSS at 0x%lx, irq %li, dma %li&%li",
 		card->shortname, codec->port, acard->irqptr->irq,
 		acard->dma1ptr->dma, acard->dma2ptr->dma);
 
