@@ -2135,7 +2135,7 @@ static int __init snd_cmipci_probe(struct pci_dev *pci,
 	}
 	strcpy(card->abbreviation, "C-Media PCI");
 	strcpy(card->shortname, "C-Media PCI");
-	sprintf(card->longname, "%s %s at 0x%lx, irq %i",
+	sprintf(card->longname, "%s %s at 0x%lx, irq %li",
 		card->shortname,
 		card->type == SND_CARD_TYPE_CMI8738 ? "CM8738" : "CM8338",
 		pci_resource_start(cm->pci, 0),
