@@ -137,8 +137,8 @@ static int __init snd_card_cs4231_resources(int dev,
 					    struct snd_card_cs4231 *acard,
 					    snd_card_t * card)
 {
-	static int possible_irqs[] = {-1};
-	static int possible_dmas[] = {-1};
+	static long possible_irqs[] = {-1};
+	static long possible_dmas[] = {-1};
 	int err;
 
 	if ((err = snd_register_interrupt(card, "CS4231",
@@ -221,13 +221,13 @@ static int __init snd_card_cs4231_probe(int dev, struct snd_card_cs4231 *acard)
 	}
 	strcpy(card->abbreviation, "CS4231");
 	strcpy(card->shortname, pcm->name);
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li, dma %li",
 		pcm->name,
 		codec->port,
 		acard->irqptr->irq,
 		acard->dma1ptr->dma);
 	if (acard->dma2ptr)
-		sprintf(card->longname + strlen(card->longname), "&%i",
+		sprintf(card->longname + strlen(card->longname), "&%li",
 			acard->dma2ptr->dma);
 	if (!snd_card_register(card)) {
 		acard->card = card;
