@@ -33,9 +33,11 @@ Card: Generic CS4232\n\
 Card: Turtle Beach TBS-2000\n\
 Card: Turtle Beach Tropez Plus\n\
 Card: AudioSystem EWS64\n\
+Card: SIC CrystalWave 32\n\
 ISAPNP: CSC7532=CSC0000,CSC0010,CSCb006\n\
 ISAPNP: CSC7632=CSC0000,CSC0010,PNPb006\n\
 ISAPNP: CSCa836=CSCa800,CSCa810,CSCa8a3\n\
+ISAPNP: CSCf032=CSC0000,CSC0010,CSC0003\n\
 ");
 #else
 MODULE_DESCRIPTION("\
@@ -163,6 +165,11 @@ static unsigned int snd_card_pnpids[] = {
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0xa800), /* WSS */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0xa810), /* CTRL */
 	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0xa8a3), /* MPU */
+	/* SIC CrystalWave 32 (CS4232) */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_DEVICE(0xf032),   /* DEVICE */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0000), /* WSS */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0010), /* CTRL */
+	(ISAPNP_VENDOR('C','S','C')<<16)|ISAPNP_FUNCTION(0x0003), /* MPU */
 	/* --- */
 	0	/* end */
 };
@@ -351,8 +358,8 @@ static int __init snd_card_cs4236_resources(int dev,
 					    struct snd_card_cs4236 *acard,
 					    snd_card_t * card)
 {
-	static int possible_irqs[] = {-1};
-	static int possible_dmas[] = {-1};
+	static long possible_irqs[] = {-1};
+	static long possible_dmas[] = {-1};
 	int err;
 
 	if ((err = snd_register_interrupt(card, IDENT,
@@ -431,9 +438,9 @@ static int __init snd_card_cs4236_isapnp(int dev, struct snd_card_cs4236 *acard)
 		acard->mpu = isapnp_find_dev(card, tmp >> 16, tmp & 0xffff, NULL);
 		if (acard->mpu == NULL) {
 			snd_printdd("isapnp failed for " IDENT " (MPU) - %i\n", idx);
-			goto __again;		/* maybe we have another config */
+			snd_mpu_port[dev] = -1;
 		} else if (acard->mpu->active) {
-			goto __again;
+			snd_mpu_port[dev] = -1;
 		}
 	} else {
 		snd_mpu_port[dev] = -1;
@@ -611,13 +618,13 @@ static int __init snd_card_cs4236_probe(int dev, struct snd_card_cs4236 *acard)
 	strcpy(card->abbreviation, "CS4232");
 #endif
 	strcpy(card->shortname, pcm->name);
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li, dma %li",
 		pcm->name,
 		codec->port,
 		acard->irqptr->irq,
 		acard->dma1ptr->dma);
 	if (acard->dma2ptr)
-		sprintf(card->longname + strlen(card->longname), "&%i",
+		sprintf(card->longname + strlen(card->longname), "&%li",
 			acard->dma2ptr->dma);
 	if (!snd_card_register(card)) {
 		acard->card = card;
