@@ -116,7 +116,7 @@ static int __init snd_card_es968_resources(int dev,
 					   snd_card_t *card)
 {
 	int error;
-	static int no_alternatives[] = {-1};
+	static long no_alternatives[] = {-1};
 
 	if ((error = snd_register_ioport(card, snd_port[dev], 16,
 			DRIVER_NAME" - DSP", NULL)) < 0)
@@ -229,7 +229,7 @@ static int __init snd_card_es968_probe(int dev, struct snd_card_es968 *acard)
 
 	strcpy(card->abbreviation, "ES968");
 	strcpy(card->shortname, "ESS ES968");
-	sprintf(card->longname, "%s soundcard, %s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s soundcard, %s at 0x%lx, irq %li, dma %li",
 		card->shortname, codec->name, codec->port,
 		acard->irqptr->irq, acard->dma8ptr->dma);
 
