@@ -369,8 +369,8 @@ static void snd_interwave_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 static int __init snd_interwave_resources(int dev, struct snd_interwave *iwcard,
 					  snd_card_t * card)
 {
-	static int possible_irqs[] = {5, 11, 12, 9, 7, 15, 3, -1};
-	static int possible_dmas[] = {0, 1, 3, 5, 6, 7, -1};
+	static long possible_irqs[] = {5, 11, 12, 9, 7, 15, 3, -1};
+	static long possible_dmas[] = {0, 1, 3, 5, 6, 7, -1};
 	int err;
 
 	if ((err = snd_register_interrupt(card, "InterWave", snd_irq[dev],
@@ -987,13 +987,13 @@ static int __init snd_interwave_probe(int dev, struct snd_interwave *iwcard)
 #else
 	str = "InterWave STB";
 #endif
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li, dma %li",
 		str,
 		gus->gf1.port,
 		iwcard->irqptr->irq,
 		iwcard->dma1ptr->dma);
 	if (iwcard->dma2ptr)
-		sprintf(card->longname + strlen(card->longname), "&%i",
+		sprintf(card->longname + strlen(card->longname), "&%li",
 			iwcard->dma2ptr->dma);
 	snd_gf1_start(gus);
 
