@@ -106,6 +106,8 @@ snd_rme96_probe(int dev,
 		return err;
 	
       __found:
+	if ((err = pci_enable_device(rme96->pci)) < 0)
+		return err;
 	if ((card = snd_card_new(snd_index[dev], snd_id[dev], snd_rme96_use_inc,
 				 snd_rme96_use_dec)) == NULL)
 	{
@@ -144,7 +146,7 @@ snd_rme96_probe(int dev,
 		strcpy(card->shortname, "RME Digi96/8 Pro");
 		break;
 	}
-	sprintf(card->longname, "%s at 0x%lx, irq %i", card->shortname,
+	sprintf(card->longname, "%s at 0x%lx, irq %li", card->shortname,
 		rme96->port, rme96->irqptr->irq);
 	
 	if ((err = snd_card_register(card)) < 0) {
