@@ -37,6 +37,7 @@ ISAPNP: CTL0026=CTL0031\n\
 ISAPNP: CTL0027=CTL0031\n\
 ISAPNP: CTL0028=CTL0031\n\
 ISAPNP: CTL0029=CTL0031\n\
+ISAPNP: CTL002a=CTL0031\n\
 ISAPNP: CTL002b=CTL0031\n\
 ISAPNP: CTL0051=CTL0001\n\
 ISAPNP: CTL0070=CTL0001\n\
@@ -52,6 +53,7 @@ ISAPNP: CTL0039=CTL0031,CTL0021\n\
 ISAPNP: CTL0042=CTL0031,CTL0021\n\
 ISAPNP: CTL0043=CTL0031,CTL0021\n\
 ISAPNP: CTL0044=CTL0031,CTL0021\n\
+ISAPNP: CTL0047=CTL0031,CTL0021\n\
 ISAPNP: CTL0048=CTL0031,CTL0021\n\
 ISAPNP: CTL0054=CTL0031,CTL0021\n\
 ISAPNP: CTL009c=CTL0041,CTL0021\n\
@@ -178,6 +180,9 @@ static unsigned int snd_sb16_pnpids[] = {
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x0029),   /* DEVICE */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
 	/* Sound Blaster 16 PnP */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x002a),   /* DEVICE */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
+	/* Sound Blaster 16 PnP */
 	/* Note: This card also have a CTL0051:StereoEnhance device!!! */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x002b),   /* DEVICE */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
@@ -218,6 +223,12 @@ static unsigned int snd_sb16_pnpids[] = {
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
 #ifdef SND_SBAWE_EMU8000
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0021), /* WaveTable */
+#endif
+	/* Sound Blaster AWE 32 PnP */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x0047),   /* DEVICE */
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0031), /* Audio */
+#ifdef SND_SBAWE_EMU8000
+	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_FUNCTION(0x0021), /* WaveTable */
 #endif
 	/* Sound Blaster AWE 32 PnP */
 	(ISAPNP_VENDOR('C','T','L')<<16)|ISAPNP_DEVICE(0x0048),   /* DEVICE */
@@ -398,9 +409,9 @@ static void snd_sb16_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 static int __init snd_sb16_resources(int dev, struct snd_sb16 *acard,
 				     snd_card_t * card)
 {
-	static int possible_irqs[] = {5, 9, 10, 7, -1};
-	static int possible_dmas8[] = {1, 3, 0, -1};
-	static int possible_dmas16[] = {5, 6, 7, -1};
+	static long possible_irqs[] = {5, 9, 10, 7, -1};
+	static long possible_dmas8[] = {1, 3, 0, -1};
+	static long possible_dmas16[] = {5, 6, 7, -1};
 	int err, ok = 0;
 
 	if ((err = snd_register_interrupt(card,
@@ -493,7 +504,7 @@ static int __init snd_sb16_isapnp(int dev, struct snd_sb16 *acard)
 	if (snd_mpu_port[dev] != SND_AUTO_PORT)
 		isapnp_resource_change(&pdev->resource[1], snd_mpu_port[dev], 2);
 	if (snd_fm_port[dev] != SND_AUTO_PORT)
-		isapnp_resource_change(&pdev->resource[2], snd_mpu_port[dev], 4);
+		isapnp_resource_change(&pdev->resource[2], snd_fm_port[dev], 4);
 	if (snd_dma8[dev] != SND_AUTO_DMA)
 		isapnp_resource_change(&pdev->dma_resource[0], snd_dma8[dev], 1);
 	if (snd_dma16[dev] != SND_AUTO_DMA)
@@ -529,12 +540,14 @@ static int __init snd_sb16_isapnp(int dev, struct snd_sb16 *acard)
 		return -EBUSY;
 	}
 	snd_awe_port[dev] = pdev->resource[0].start;
+#if 0
 	/* set other two ports which aren't listed in PnP EEPROM */
 	/* FIXME: remove for 2.4!!! */
 	isapnp_cfg_begin(pdev->bus->number, pdev->devfn);
 	isapnp_write_word(ISAPNP_CFG_PORT + (1 << 1), snd_awe_port[dev] + (0xa40 - 0x640));
 	isapnp_write_word(ISAPNP_CFG_PORT + (2 << 1), snd_awe_port[dev] + (0xe40 - 0x640));
 	isapnp_cfg_end();
+#endif
 	snd_printdd("isapnp SB16: wavetable port=0x%lx\n", pdev->resource[0].start);
 #endif
 	return 0;
@@ -673,15 +686,15 @@ static int __init snd_sb16_probe(int dev, struct snd_sb16 *acard)
 
 	strcpy(card->abbreviation, "SB16");
 	strcpy(card->shortname, "Sound Blaster 16");
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma ",
+	sprintf(card->longname, "%s at 0x%lx, irq %li, dma ",
 		codec->name,
 		codec->port,
 		acard->irqptr->irq);
 	if (acard->dma8ptr)
-		sprintf(card->longname + strlen(card->longname), "%i",
+		sprintf(card->longname + strlen(card->longname), "%li",
 			acard->dma8ptr->dma);
 	if (acard->dma16ptr)
-		sprintf(card->longname + strlen(card->longname), "%s%i",
+		sprintf(card->longname + strlen(card->longname), "%s%li",
 			acard->dma8ptr ? "&" : "",
 			acard->dma16ptr->dma);
 	if (!snd_card_register(card)) {
