@@ -285,8 +285,8 @@ static void snd_sgalaxy_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 static int snd_sgalaxy_resources(int dev, struct snd_sgalaxy *acard, 
 				 snd_card_t *card)
 {
-	static int possible_irqs[] = {7, 9, 10, 11, -1};
-	static int possible_dmas[] = {1, 3, 0, -1};
+	static long possible_irqs[] = {7, 9, 10, 11, -1};
+	static long possible_dmas[] = {1, 3, 0, -1};
 	int err;
 
 #if 0
@@ -461,7 +461,7 @@ static int __init snd_sgalaxy_probe(int dev, struct snd_sgalaxy *acard)
 #endif
 	strcpy(card->abbreviation, "Sound Galaxy");
 	strcpy(card->shortname, "Sound Galaxy");
-	sprintf(card->longname, "Sound Galaxy at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "Sound Galaxy at 0x%x, irq %li, dma %li",
 		snd_wssport[dev],
 		acard->irqptr->irq,
 		acard->dma1ptr->dma);
