@@ -245,10 +245,10 @@ static void snd_card_share_playback_ack_begin(snd_pcm_subchn_t *subchn)
 
 	if (runtime->dma_area->buf == NULL)
 		return;
-	spin_lock_irq(&pcmo->run_lock);
+	spin_lock(&pcmo->run_lock);
 	mix(subchn, pcmo, 1, runtime->buf.block.frag_size);
 	mix(subchn, pcmo, 2, 128);
-	spin_unlock_irq(&pcmo->run_lock);
+	spin_unlock(&pcmo->run_lock);
 }
 
 static void cdivide1(snd_card_share_pcm_t *dpcm, 
@@ -313,10 +313,10 @@ static void snd_card_share_capture_ack_begin(snd_pcm_subchn_t *subchn)
 
 	if (runtime->dma_area->buf == NULL)
 		return;
-	spin_lock_irq(&pcmo->run_lock);
+	spin_lock(&pcmo->run_lock);
 	if (pcmo->run_pcm_list != NULL)
 		cdivide(subchn, pcmo, runtime->buf.block.frag_size);
-	spin_unlock_irq(&pcmo->run_lock);
+	spin_unlock(&pcmo->run_lock);
 }
 
 static void snd_card_share_pcm_ack_end(snd_pcm_subchn_t *subchn)
@@ -325,7 +325,7 @@ static void snd_card_share_pcm_ack_end(snd_pcm_subchn_t *subchn)
 	snd_card_share_pcm_open_t *pcmo = snd_magic_cast(snd_card_share_pcm_open_t, runtime->private_data, );
 	snd_card_share_pcm_t *dpcm, *dpcm_next;
 
-	spin_lock_irq(&pcmo->run_lock);
+	spin_lock(&pcmo->run_lock);
 	dpcm = pcmo->run_pcm_list;
 	while (dpcm) {
 		dpcm->pcm_buf_pos += runtime->buf.block.frag_size;
@@ -333,7 +333,7 @@ static void snd_card_share_pcm_ack_end(snd_pcm_subchn_t *subchn)
 		snd_pcm_transfer_done(dpcm->subchn);
 		dpcm = dpcm_next;
 	}
-	spin_unlock_irq(&pcmo->run_lock);
+	spin_unlock(&pcmo->run_lock);
 }
 
 static int snd_card_share_playback_ioctl(void *private_data,
