@@ -388,8 +388,8 @@ static int __init snd_wavefront_resources(int dev,
 					  snd_wavefront_card_t *acard,
 					  snd_card_t * card)
 {
-	static int possible_irqs[] = {-1};
-	static int possible_dmas[] = {-1};
+	static long possible_irqs[] = {-1};
+	static long possible_dmas[] = {-1};
 	int err;
 	
 	/* First, see if we can access the relevant ports */
@@ -863,25 +863,25 @@ snd_wavefront_probe (int dev, snd_wavefront_card_t *acard)
 	   length restrictions
 	*/
 
-	sprintf(card->longname, "%s PCM 0x%x irq %i dma%i",
+	sprintf(card->longname, "%s PCM 0x%lx irq %li dma%li",
 		card->abbreviation,
 		codec->port,
 		acard->cs4232_pcm_irqptr->irq,
 		acard->dma1ptr->dma);
 
 	if (acard->dma2ptr)
-		sprintf(card->longname + strlen(card->longname), "&%i",
+		sprintf(card->longname + strlen(card->longname), "&%li",
 			acard->dma2ptr->dma);
 
 	if (snd_cs4232_mpu_port[dev] != SND_AUTO_PORT) {
 		sprintf (card->longname + strlen (card->longname), 
-			 " MPU-401 0x%x irq %i",
+			 " MPU-401 0x%x irq %li",
 			 snd_cs4232_mpu_port[dev],
 			 acard->cs4232_mpu_irqptr->irq);
 	}
 
 	sprintf (card->longname + strlen (card->longname), 
-		 " SYNTH 0x%x irq %i",
+		 " SYNTH 0x%x irq %li",
 		 snd_ics2115_port[dev],
 		 acard->ics2115_irqptr->irq);
 
