@@ -88,8 +88,10 @@
 #define SND_CARD_TYPE_VIA82C686A	0x00000036	/* VIA 82C686A */
 #define SND_CARD_TYPE_FM801		0x00000037	/* FM801 */
 #define SND_CARD_TYPE_AZT2320		0x00000038	/* AZT2320 */
+#define SND_CARD_TYPE_PRODIF_PLUS	0x00000039	/* Marian/Sek'D Prodif Plus */
+#define SND_CARD_TYPE_YMFPCI		0x0000003a	/* YMF724/740/744/754 */
 
 /* --- */
-#define SND_CARD_TYPE_LAST		0x00000038
+#define SND_CARD_TYPE_LAST		0x0000003a
 
 #endif				/* __ASOUNDID_H */
