@@ -302,7 +302,7 @@ struct snd_stru_ensoniq {
 	snd_dma_t * dma3ptr;	/* DAC2 */
 	snd_irq_t * irqptr;
 
-	unsigned int port;
+	unsigned long port;
 	unsigned int mode;
 	unsigned int uartm;	/* UART mode */
 
