@@ -173,7 +173,7 @@ struct snd_stru_dma_area {
 	 mmaped:1,			/* mmaped area to user space */
 	 mmap_free:1;			/* free mmaped buffer */
 	unsigned char *buf;		/* pointer to DMA buffer */
-	long size;			/* real size of DMA buffer */
+	unsigned long size;		/* real size of DMA buffer */
 	char *owner;			/* owner of this DMA channel */
 	snd_dma_t *dma;
 	snd_dma_area_t *next;
@@ -182,7 +182,7 @@ struct snd_stru_dma_area {
 struct snd_stru_dma {
 	int type;			/* dma type - see SND_DMA_TYPE_XXXX */
 	int multi: 1;			/* multi area support */
-	int dma;			/* DMA number */
+	unsigned long dma;		/* DMA number */
 	int addressbits;		/* physical wired bits (24-64) */
 	char *name;			/* pointer to name */
 	long rsize;			/* requested size of DMA buffer */
@@ -198,15 +198,15 @@ struct snd_stru_dma {
 
 typedef struct snd_stru_irq {
 	int type;		/* see to SND_IRQ_TYPE_XXXX */
-	unsigned short irq;
+	unsigned long irq;
 	char *name;
 	void *dev_id;
 	struct snd_stru_irq *next;
 } snd_irq_t;
 
 typedef struct snd_stru_port {
-	unsigned int port;
-	unsigned int size;
+	unsigned long port;
+	unsigned long size;
 	char *name;
 #ifdef LINUX_2_3
 	struct resource *res;
@@ -432,20 +432,21 @@ extern int snd_card_unregister(snd_card_t * card);
 extern int snd_card_info_init(void);
 extern int snd_card_info_done(void);
 
-extern int snd_check_ioport(snd_card_t * card, int port, int size);
-extern int snd_register_ioport(snd_card_t * card, int port, int size, char *name,
-                               snd_port_t ** rport);
+extern int snd_check_ioport(snd_card_t * card, unsigned long port, unsigned long size);
+extern int snd_register_ioport(snd_card_t * card,
+			       unsigned long port, unsigned long size,
+			       char *name, snd_port_t ** rport);
 extern int snd_unregister_ioport(snd_card_t * card, snd_port_t * port);
 extern int snd_unregister_ioports(snd_card_t * card);
 
-extern int snd_register_dma_channel(snd_card_t * card, char *name, int number,
-				    int type, int rsize, int *possible_numbers,
+extern int snd_register_dma_channel(snd_card_t * card, char *name, unsigned long number,
+				    int type, long rsize, long *possible_numbers,
 				    snd_dma_t ** rdma);
 extern int snd_unregister_dma_channels(snd_card_t * card);
 
-extern int snd_register_interrupt(snd_card_t * card, char *name, int number,
+extern int snd_register_interrupt(snd_card_t * card, char *name, unsigned long number,
 				  int type, snd_irq_handler_t * handler,
-				  void *dev_id, int *possible_numbers,
+				  void *dev_id, long *possible_numbers,
 				  snd_irq_t ** rirq);
 extern int snd_unregister_interrupts(snd_card_t * card);
 
