@@ -256,18 +256,19 @@ int __exit snd_card_info_done(void)
  *  I/O port registration
  */
 
-int snd_check_ioport(snd_card_t * card, int port, int size)
+int snd_check_ioport(snd_card_t * card, unsigned long port, unsigned long size)
 {
 	snd_debug_check(card == NULL, -ENXIO);
 	if (check_region(port, size)) {
-		snd_printdd("check - ports 0x%x-0x%x busy\n", port, port + size - 1);
+		snd_printdd("check - ports 0x%lx-0x%lx busy\n", port, port + size - 1);
 		return -EBUSY;
 	}
 	return 0;
 }
 
-int snd_register_ioport(snd_card_t * card, int port, int size, char *name,
-                        snd_port_t ** rport)
+int snd_register_ioport(snd_card_t * card,
+			unsigned long port, unsigned long size,
+			char *name, snd_port_t ** rport)
 {
 	char *xname;
 	snd_port_t *pport, *pport1;
@@ -361,8 +362,8 @@ int snd_unregister_ioports(snd_card_t * card)
  *  DMA channel registration
  */
 
-int snd_register_dma_channel(snd_card_t * card, char *name, int number,
-			     int type, int rsize, int *possible_numbers,
+int snd_register_dma_channel(snd_card_t * card, char *name, unsigned long number,
+			     int type, long rsize, long *possible_numbers,
 			     snd_dma_t ** rdma)
 {
 	snd_dma_t *dmaptr, *dmaptr1;
@@ -436,7 +437,7 @@ int snd_register_dma_channel(snd_card_t * card, char *name, int number,
 	init_MUTEX(&dmaptr->mutex);
 	if (type == SND_DMA_TYPE_ISA) {
 		if (request_dma(number, dmaptr->name)) {
-			snd_printk("unable to grab DMA %i for %s\n",
+			snd_printk("unable to grab DMA %li for %s\n",
 						number, dmaptr->name);
 			snd_kfree(dmaptr->name);
 			snd_kfree(dmaptr);
@@ -477,9 +478,9 @@ int snd_unregister_dma_channels(snd_card_t * card)
  *  IRQ channel registration
  */
 
-int snd_register_interrupt(snd_card_t * card, char *name, int number,
+int snd_register_interrupt(snd_card_t * card, char *name, unsigned long number,
 			   int type, snd_irq_handler_t * handler,
-			   void *dev_id, int *possible_numbers,
+			   void *dev_id, long *possible_numbers,
 			   snd_irq_t ** rirq)
 {
 	int sa_flags;
@@ -537,7 +538,7 @@ int snd_register_interrupt(snd_card_t * card, char *name, int number,
 		return -ENOMEM;
 	}
 	if (request_irq(number, handler, sa_flags, xname, dev_id)) {
-		snd_printk("unable to grab IRQ %i for %s\n", number, xname);
+		snd_printk("unable to grab IRQ %li for %s\n", number, xname);
 		snd_kfree(xname);
 		snd_kfree(irqptr);
 		return -EBUSY;
