@@ -39,13 +39,11 @@ void *snd_malloc_pages(unsigned long size, int *res_pg, int dma)
 
 	for (pg = 0; PAGE_SIZE * (1 << pg) < size; pg++);
 	buf = (void *) __get_free_pages(GFP_KERNEL | (dma ? GFP_DMA : 0), pg);
-	if (buf) {
-		int page, last_page;
-
-		page = MAP_NR(buf);
-		last_page = page + (1 << pg);
+	if (buf != NULL) {
+		mem_map_t *page = virt_to_page(buf);
+		mem_map_t *last_page = virt_to_page(buf) + (1 << pg);
 		while (page < last_page)
-			set_bit(PG_reserved, &mem_map[page++].flags);
+			set_bit(PG_reserved, &(page++)->flags);
 		snd_alloc_pages += 1 << pg;
 	}
 	if (res_pg)
@@ -55,15 +53,16 @@ void *snd_malloc_pages(unsigned long size, int *res_pg, int dma)
 
 void snd_free_pages(void *ptr, unsigned long size)
 {
-	int pg, page, last_page;
+	int pg;
+	mem_map_t *page, *last_page;
 
 	if (ptr == NULL)
 		return;
 	for (pg = 0; PAGE_SIZE * (1 << pg) < size; pg++);
-	page = MAP_NR(ptr);
-	last_page = page + (1 << pg);
+	page = virt_to_page(ptr);
+	last_page = virt_to_page(ptr) + (1 << pg);
 	while (page < last_page)
-		clear_bit(PG_reserved, &mem_map[page++].flags);
+		clear_bit(PG_reserved, &(page++)->flags);
 	free_pages((unsigned long) ptr, pg);
 	snd_alloc_pages -= 1 << pg;
 }
