@@ -93,7 +93,7 @@ static int snd_mixer_oss_set_recsrc(snd_kmixer_t *mixer, int recsrc)
 	snd_kmixer_group_t *group;
 	snd_mixer_group_t g;
 	snd_kmixer_file_t mfile;
-	int caps;
+	int caps, result = 0;
 
 	caps = snd_mixer_oss_caps(mixer);
 	snd_mixer_oss_mfile(&mfile, mixer);
@@ -113,6 +113,7 @@ static int snd_mixer_oss_set_recsrc(snd_kmixer_t *mixer, int recsrc)
 			continue;
 		if (recsrc & (1 << group->oss_dev)) {
 			g.capture = g.channels;
+			result |= 1 << group->oss_dev;
 		} else {
 			g.capture = 0;
 		}
@@ -120,7 +121,7 @@ static int snd_mixer_oss_set_recsrc(snd_kmixer_t *mixer, int recsrc)
 			snd_mixer_group_value_change_all(mixer, group, 0);
 	}
 	snd_mixer_lock(mixer, 1);
-	return 0;
+	return result;
 }
 
 static int snd_mixer_oss_devmask(snd_kmixer_t *mixer)
@@ -219,7 +220,7 @@ static int snd_mixer_oss_recsrc(snd_kmixer_t *mixer)
 		if (group->control(group, NULL, 0, &g) < 0)
 			continue;
 		if (g.caps & SND_MIXER_GRPCAP_CAPTURE) {
-			if ((g.capture & SND_MIXER_CHN_MASK_STEREO) == SND_MIXER_CHN_MASK_STEREO)
+			if ((g.capture & g.channels) == g.channels)
 				result |= 1 << group->oss_dev;
 		}
 	}
