@@ -1117,7 +1117,7 @@ static long snd_pcm_lib_write_block(snd_pcm_subchn_t *subchn, const void *src, u
 				return result > 0 ? result : -EAGAIN;
 			timeout = interruptible_sleep_on_timeout(&runtime->sleep, 10 * HZ);
 			if (signal_pending(current))
-				return !result ? result : -EINTR;
+				return result > 0 ? result : -EINTR;
 			if (!timeout && !snd_pcm_playback_ok(subchn)) {
 				snd_printd("playback write error (DMA or IRQ trouble?)\n");
 				return result > 0 ? result : -EIO;
@@ -1475,7 +1475,7 @@ static long snd_pcm_lib_read_block(snd_pcm_subchn_t *subchn, void *dst, unsigned
 				return result > 0 ? result : -EAGAIN;
 			timeout = interruptible_sleep_on_timeout(&runtime->sleep, 10 * HZ);
 			if (signal_pending(current))
-				return !result ? result : -EINTR;
+				return result > 0 ? result : -EINTR;
 			if (!timeout && !snd_pcm_capture_ok(subchn)) {
 				snd_printd("capture read error (DMA or IRQ trouble?)\n");
 				return result > 0 ? result : -EIO;
