@@ -244,10 +244,6 @@ static int snd_rawmidi_open(unsigned short minor, int cardnum, int device,
 	if (rmidi == NULL)
 		return -ENODEV;
 
-#ifdef CONFIG_SND_OSSEMUL
-	if (minor < 256)
-		file->f_flags |= O_NONBLOCK;
-#endif
 	fflags = snd_rawmidi_file_flags(file);
 	if ((file->f_flags & O_APPEND) && !(file->f_flags & O_NONBLOCK))
 		return -EINVAL;		/* invalid combination */
