@@ -90,6 +90,7 @@ snd_seq_kinstr_list_t *snd_seq_instr_list_new(void)
 	spin_lock_init(&list->lock);
 	spin_lock_init(&list->ops_lock);
 	init_MUTEX(&list->ops_mutex);
+	list->owner = -1;
 	return list;
 }
 
@@ -380,12 +381,11 @@ static int instr_end(snd_seq_kinstr_ops_t *ops,
 
 	/* TODO: timeout handling */
 	spin_lock_irqsave(&list->lock, flags);
-	if (list->owner >= 0 && list->owner != ev->source.client) {
+	if (list->owner == ev->source.client) {
 		list->owner = -1;
 		spin_unlock_irqrestore(&list->lock, flags);
 		return instr_result(ev, SND_SEQ_EVENT_INSTR_END, 0, atomic);
 	}
-	list->owner = ev->source.client;
 	spin_unlock_irqrestore(&list->lock, flags);
 	return instr_result(ev, SND_SEQ_EVENT_INSTR_END, -EINVAL, atomic);
 }
@@ -500,6 +500,7 @@ static int instr_put(snd_seq_kinstr_ops_t *ops,
 	spin_lock_irqsave(&list->lock, flags);
 	instr->next = list->hash[key];
 	list->hash[key] = instr;
+	list->count++;
 	spin_unlock_irqrestore(&list->lock, flags);
 	snd_instr_unlock_ops(list);
 	result = 0;
