@@ -867,10 +867,6 @@ static int snd_virmidi_dispatch_event(snd_virmidi_t *rmidi,
 	result = snd_seq_kernel_client_dispatch(rmidi->client, ev, 0, 0);
 #endif
 
-	/* free sysex record */
-	if (snd_seq_ev_is_variable(ev) && ev->data.ext.ptr)
-		snd_seq_ext_free(ev->data.ext.ptr, ev->data.ext.len);
-
 	return result;
 }
 
