@@ -503,7 +503,7 @@ static int __init alsa_sound_init(void)
 		return err;
 #endif
 #ifdef CONFIG_DEVFS_FS
-	devfs_handle = devfs_mk_dir(NULL, "snd", 0, NULL);
+	devfs_handle = devfs_mk_dir(NULL, "snd", NULL);
 	if (devfs_register_chrdev(snd_major, "alsa", &snd_fops)) {
 #else
 	if (register_chrdev(snd_major, "alsa", &snd_fops)) {
@@ -529,9 +529,9 @@ static int __init alsa_sound_init(void)
 #ifdef CONFIG_DEVFS_FS
 	for (controlnum = 0; controlnum < snd_cards_limit; controlnum++) {
 		sprintf(controlname, "snd/controlC%d", controlnum);
-		devfs_register(NULL, controlname, 0, DEVFS_FL_DEFAULT,
+		devfs_register(NULL, controlname, DEVFS_FL_DEFAULT,
 				snd_major, controlnum<<5, snd_device_mode | S_IFCHR,
-				0, 0, &snd_fops, NULL);
+				&snd_fops, NULL);
 	}
 #endif
 #ifndef MODULE
@@ -565,7 +565,7 @@ static void __exit alsa_sound_exit(void)
 
 	for (controlnum = 0; controlnum < snd_cards_limit; controlnum++) {
 		sprintf(controlname, "snd/controlC%d", controlnum);
-		master = devfs_find_handle(NULL, controlname, 0, 0, 0, DEVFS_SPECIAL_CHR, 0);
+		master = devfs_find_handle(NULL, controlname, 0, 0, DEVFS_SPECIAL_CHR, 0);
 		devfs_unregister(master);
 	}
 #endif
