@@ -136,7 +136,7 @@ static void snd_emu10k1_init_efx(emu10k1_t *emu)
 static int snd_emu10k1_init(emu10k1_t * emu)
 {
 	int ch, idx;
-	unsigned int silent_page, tmp;
+	unsigned int silent_page;
 
 	/* disable audio and lock cache */
 	outl(HCFG_LOCKSOUNDCACHE | HCFG_LOCKTANKCACHE | HCFG_MUTEBUTTONENABLE, emu->port + HCFG);
@@ -229,10 +229,10 @@ static int snd_emu10k1_init(emu10k1_t * emu)
 	 *  Clear page with silence & setup all pointers to this page
 	 */
 	memset(emu->silent_page, 0, PAGE_SIZE);
-	silent_page = (unsigned int)virt_to_phys(emu->silent_page) << 1;
+	silent_page = (unsigned int)virt_to_bus(emu->silent_page) << 1;
 	for (idx = 0; idx < MAXPAGES; idx++)
 		emu->ptb_pages[idx] = silent_page | idx; 
-	snd_emu10k1_ptr_write(emu, PTB, 0, virt_to_phys(emu->ptb_pages));
+	snd_emu10k1_ptr_write(emu, PTB, 0, virt_to_bus((void *)emu->ptb_pages));
 	snd_emu10k1_ptr_write(emu, TCB, 0, 0);	/* taken from original driver */
 	snd_emu10k1_ptr_write(emu, TCBS, 0, 4);	/* taken from original driver */
 
@@ -259,6 +259,8 @@ static int snd_emu10k1_init(emu10k1_t * emu)
 		outl(HCFG_AUDIOENABLE | HCFG_LOCKTANKCACHE | HCFG_AUTOMUTE | HCFG_JOYENABLE, emu->port + HCFG);
 
 #if 0
+	{
+	unsigned int tmp;
 	/* FIXME: the following routine disables LiveDrive-II !! */
 	// TOSLink detection
 	emu->tos_link = 0;
@@ -271,6 +273,7 @@ static int snd_emu10k1_init(emu10k1_t * emu)
 			outl(tmp, emu->port + HCFG);
 		}
 	}
+	}
 #endif
 
 	snd_emu10k1_intr_enable(emu, INTE_PCIERRORENABLE);
@@ -565,12 +568,14 @@ int snd_emu10k1_create(snd_card_t * card,
 	emu->port = pci_resource_start(pci, 0);
 
 	emu->ptb_pages = snd_malloc_pages(32 * 1024, NULL, 0);
-	if (emu->ptb_pages == NULL || ((long)virt_to_phys(emu->ptb_pages) & ~0x7fffffffUL)) {
+	if (emu->ptb_pages == NULL || ((long)virt_to_bus((void *)emu->ptb_pages) & ~0x7fffffffUL)) {
+		snd_printk(__PRETTY_FUNCTION__ ": PTB pages ptr > 2GB limit, giving up\n");
 		snd_emu10k1_free(emu);
 		return -ENOMEM;
 	}
 	emu->silent_page = snd_malloc_pages(EMUPAGESIZE, NULL, 0);
-	if (emu->silent_page == NULL || ((long)virt_to_phys(emu->silent_page) & ~0x7fffffffUL)) {
+	if (emu->silent_page == NULL || ((long)virt_to_bus(emu->silent_page) & ~0x7fffffffUL)) {
+		snd_printk(__PRETTY_FUNCTION__ ": Silent page ptr > 2GB limit, giving up\n");
 		snd_emu10k1_free(emu);
 		return -ENOMEM;
 	}
