@@ -56,6 +56,7 @@ static struct {
 	char *name;
 } snd_ac97_codec_ids[] = {
 	{	0x414b4d00,	"AK4540"			},
+	{	0x414b4d01,	"AK4542",			},
 	{	0x414b4d02,	"AK4543",			},
 	{	0x41445303,	"AD1819"			},
 	{	0x41445340,	"AD1881"			},
@@ -124,6 +125,7 @@ static int snd_ac97_valid_reg(ac97_t *ac97, unsigned short reg)
 {
 	switch (ac97->id) {
 	case 0x414B4D00:	/* AK4540 */
+	case 0x414B4D01:	/* AK4542 */
 		if (reg <= 0x1c || reg == 0x20 || reg == 0x26 || reg >= 0x7c)
 			return 1;
 		return 0;
