@@ -639,7 +639,7 @@ static void snd_ad1816a_free(void *private_data)
 }
 
 int snd_ad1816a_new_pcm(snd_card_t *card, int device,
-			unsigned short port, snd_irq_t *irqptr,
+			unsigned long port, snd_irq_t *irqptr,
 			snd_dma_t *dma1ptr, snd_dma_t *dma2ptr,
 			int timer_dev, snd_pcm_t **rpcm)
 {
