@@ -76,8 +76,8 @@ static unsigned char snd_cs4231_original_image[32] =
 	0x00,			/* 0f/15 - pbrl */
 	0x80,			/* 10/16 - afei */
 	0x01,			/* 11/17 - afeii */
-	0x00,			/* 12/18 - llic */
-	0x00,			/* 13/19 - rlic */
+	0x80,			/* 12/18 - llic */
+	0x80,			/* 13/19 - rlic */
 	0x00,			/* 14/20 - tlb */
 	0x00,			/* 15/21 - thb */
 	0x00,			/* 16/22 - la3mic/reserved */
@@ -276,7 +276,7 @@ void snd_cs4231_mce_up(cs4231_t * codec)
 	codec->mce_bit |= CS4231_MCE;
 	timeout = inb(CS4231P(codec, REGSEL));
 	if (timeout == 0x80)
-		snd_printk("snd_cs4231_up [0x%x]: serious init problem - codec still busy\n", codec->port);
+		snd_printk("snd_cs4231_up [0x%lx]: serious init problem - codec still busy\n", codec->port);
 	if (!(timeout & CS4231_MCE))
 		outb(codec->mce_bit | (timeout & 0x1f), CS4231P(codec, REGSEL));
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
@@ -295,13 +295,13 @@ void snd_cs4231_mce_down(cs4231_t * codec)
 #endif
 #ifdef CONFIG_SND_DEBUG
 	if (inb(CS4231P(codec, REGSEL)) & CS4231_INIT)
-		snd_printk("cs4231_mce_down [0x%x] - auto calibration time out (0)\n", CS4231P(codec, REGSEL));
+		snd_printk("cs4231_mce_down [0x%lx] - auto calibration time out (0)\n", CS4231P(codec, REGSEL));
 #endif
 	codec->mce_bit &= ~CS4231_MCE;
 	timeout = inb(CS4231P(codec, REGSEL));
 	outb(codec->mce_bit | (timeout & 0x1f), CS4231P(codec, REGSEL));
 	if (timeout == 0x80)
-		snd_printk("snd_cs4231_down [0x%x]: serious init problem - codec still busy\n", codec->port);
+		snd_printk("snd_cs4231_down [0x%lx]: serious init problem - codec still busy\n", codec->port);
 	if ((timeout & CS4231_MCE) == 0 ||
 	    !(codec->hardware & (CS4231_HW_CS4231_MASK | CS4231_HW_CS4232_MASK))) {
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
@@ -1331,7 +1331,7 @@ static void snd_cs4231_resume(cs4231_t * codec)
 	timeout = inb(CS4231P(codec, REGSEL));
 	outb(codec->mce_bit | (timeout & 0x1f), CS4231P(codec, REGSEL));
 	if (timeout == 0x80)
-		snd_printk("snd_cs4231_down [0x%x]: serious init problem - codec still busy\n", codec->port);
+		snd_printk("snd_cs4231_down [0x%lx]: serious init problem - codec still busy\n", codec->port);
 	if ((timeout & CS4231_MCE) == 0 ||
 	    !(codec->hardware & (CS4231_HW_CS4231_MASK | CS4231_HW_CS4232_MASK))) {
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
@@ -1368,7 +1368,7 @@ static void snd_cs4231_free(void *private_data)
 }
 
 int snd_cs4231_new_pcm(snd_card_t * card, int device,
-	               unsigned short port,
+	               unsigned long port,
 		       snd_irq_t * irqptr,
 		       snd_dma_t * dmaptr1,
 		       snd_dma_t * dmaptr2,
