@@ -263,8 +263,8 @@ static void snd_cs4236_resume(cs4231_t * codec)
 }
 
 int snd_cs4236_new_pcm(snd_card_t * card, int device,
-		       unsigned short port,
-		       unsigned short cport,	/* control port */
+		       unsigned long port,
+		       unsigned long cport,	/* control port */
 		       snd_irq_t * irqptr,
 		       snd_dma_t * dmaptr1,
 		       snd_dma_t * dmaptr2,
@@ -299,7 +299,7 @@ int snd_cs4236_new_pcm(snd_card_t * card, int device,
 		ver2 = snd_cs4236_ext_in(codec, CS4236_VERSION);
 		snd_printdd("CS4236: [0x%x] C1 (version) = 0x%x, ext = 0x%x\n", cport, ver1, ver2);
 		if (ver1 != ver2) {
-			snd_printk("CS4236+ chip detected, but control port 0x%x is not valid\n", cport);
+			snd_printk("CS4236+ chip detected, but control port 0x%lx is not valid\n", cport);
 			snd_device_free(card, pcm);
 			return -ENODEV;
 		}
