@@ -50,22 +50,22 @@
 
 static void snd_cs461x_poke(cs461x_t *codec, unsigned long reg, unsigned int val)
 {
-	codec->ba1.idx[(reg >> 16) & 3][(reg >> 2) & 0x3fff] = val;
+	writel(val, &codec->ba1.idx[(reg >> 16) & 3][(reg >> 2) & 0x3fff]);
 }
 
 static unsigned int snd_cs461x_peek(cs461x_t *codec, unsigned long reg)
 {
-	return codec->ba1.idx[(reg >> 16) & 3][(reg >> 2) & 0x3fff];
+	return readl(&codec->ba1.idx[(reg >> 16) & 3][(reg >> 2) & 0x3fff]);
 }
 
 static void snd_cs461x_pokeBA0(cs461x_t *codec, unsigned long reg, unsigned int val)
 {
-	codec->ba0[reg >> 2] = val;
+	writel(val, &codec->ba0[reg >> 2]);
 }
 
 static unsigned int snd_cs461x_peekBA0(cs461x_t *codec, unsigned long reg)
 {
-	return codec->ba0[reg >> 2];
+	return readl(&codec->ba0[reg >> 2]);
 }
 
 static void snd_cs461x_codec_write(void *private_data,
@@ -845,7 +845,7 @@ static int snd_cs461x_capture_prepare(void *private_data,
 	codec->cffc = 0;
 	if (runtime->format.voices < 2)
 		codec->cff <<= 1;
-	if (!snd_pcm_format_width(runtime->format.format) == 16)
+	if (snd_pcm_format_width(runtime->format.format) != 16)
 		codec->cff <<= 1;
 	return 0;
 }
@@ -860,7 +860,7 @@ static unsigned int snd_cs461x_playback_pointer(void *private_data,
 	result = snd_cs461x_peek(codec, BA1_PBA) - virt_to_bus(codec->pbuf);
 	if (result > 2048)
 		result -= 2048;
-	if (!snd_pcm_format_width(runtime->format.format) == 16)
+	if (snd_pcm_format_width(runtime->format.format) != 16)
 		result >>= 1;
 	return result;
 }
@@ -875,7 +875,7 @@ static unsigned int snd_cs461x_capture_pointer(void *private_data,
 	result = snd_cs461x_peek(codec, BA1_CBA) - virt_to_bus(codec->cbuf);
 	if (result > 2048)
 		result -= 2048;
-	if (!snd_pcm_format_width(runtime->format.format) == 16)
+	if (snd_pcm_format_width(runtime->format.format) != 16)
 		result >>= 1;
 	return result;
 }
