@@ -58,6 +58,7 @@
  */
 
 #define POLL_COUNT	0x1000
+#define IO_DELAY	10
 
 #ifdef CHIP1370
 static unsigned char bugbuf[16] __attribute__ ((aligned (16)));
@@ -82,7 +83,7 @@ static unsigned int snd_es1371_wait_src_ready(ensoniq_t * ensoniq)
 			return r;
 		udelay(1);
 	}
-	snd_printk("es1371: wait source ready timeout 0x%x [0x%x]\n", ES_REG(ensoniq, 1371_SMPRATE), r);
+	snd_printk("es1371: wait source ready timeout 0x%lx [0x%x]\n", ES_REG(ensoniq, 1371_SMPRATE), r);
 	return 0;
 }
 
@@ -108,6 +109,7 @@ static unsigned int snd_es1371_src_read(ensoniq_t * ensoniq, unsigned short reg)
 			temp = inl(ES_REG(ensoniq, 1371_SMPRATE));
 			if ((temp & 0x00870000) == 0x00010000)
 				break;
+			udelay(IO_DELAY);
 		}
 	}
 
@@ -144,7 +146,7 @@ static void snd_es1370_codec_write(void *private_data,
 	long time = HZ / 10;
 
 #if 0
-	printk("CODEC WRITE: reg = 0x%x, val = 0x%x (0x%x), creg = 0x%x\n", reg, val, ES_1370_CODEC_WRITE(reg, val), ES_REG(ensoniq, 1370_CODEC));
+	printk("CODEC WRITE: reg = 0x%x, val = 0x%x (0x%x), creg = 0x%lx\n", reg, val, ES_1370_CODEC_WRITE(reg, val), ES_REG(ensoniq, 1370_CODEC));
 #endif
 	do {
 		spin_lock_irqsave(&ensoniq->reg_lock, flags);
@@ -181,13 +183,17 @@ static void snd_es1371_codec_write(void *private_data,
 			     ES_REG(ensoniq, 1371_SMPRATE));
 			/* wait for not busy (state 0) first to avoid
 			   transition states */
-			for (t = 0; t < POLL_COUNT; t++)
+			for (t = 0; t < POLL_COUNT; t++) {
 				if ((inl(ES_REG(ensoniq, 1371_SMPRATE)) & 0x00870000) == 0x00000000)
 					break;
+				udelay(IO_DELAY);
+			}
 			/* wait for a SAFE time to write addr/data and then do it, dammit */
-			for (t = 0; t < POLL_COUNT; t++)
+			for (t = 0; t < POLL_COUNT; t++) {
 				if ((inl(ES_REG(ensoniq, 1371_SMPRATE)) & 0x00870000) == 0x00010000)
 					break;
+				udelay(IO_DELAY);
+			}
 			outl(ES_1371_CODEC_WRITE(reg, val), ES_REG(ensoniq, 1371_CODEC));
 			/* restore SRC reg */
 			snd_es1371_wait_src_ready(ensoniq);
@@ -197,7 +203,7 @@ static void snd_es1371_codec_write(void *private_data,
 		}
 		spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
 	}
-	snd_printk("es1371: codec write timeout at 0x%x [0x%x]\n", ES_REG(ensoniq, 1371_CODEC), inl(ES_REG(ensoniq, 1371_CODEC)));
+	snd_printk("es1371: codec write timeout at 0x%lx [0x%x]\n", ES_REG(ensoniq, 1371_CODEC), inl(ES_REG(ensoniq, 1371_CODEC)));
 }
 
 static unsigned short snd_es1371_codec_read(void *private_data,
@@ -218,21 +224,27 @@ static unsigned short snd_es1371_codec_read(void *private_data,
 			     ES_REG(ensoniq, 1371_SMPRATE));
 			/* wait for not busy (state 0) first to avoid
 			   transition states */
-			for (t = 0; t < POLL_COUNT; t++)
+			for (t = 0; t < POLL_COUNT; t++) {
 				if ((inl(ES_REG(ensoniq, 1371_SMPRATE)) & 0x00870000) == 0x00000000)
 					break;
+				udelay(IO_DELAY);
+			}
 			/* wait for a SAFE time to write addr/data and then do it, dammit */
-			for (t = 0; t < POLL_COUNT; t++)
+			for (t = 0; t < POLL_COUNT; t++) {
 				if ((inl(ES_REG(ensoniq, 1371_SMPRATE)) & 0x00870000) == 0x00010000)
 					break;
+				udelay(IO_DELAY);
+			}
 			outl(ES_1371_CODEC_READS(reg), ES_REG(ensoniq, 1371_CODEC));
 			/* restore SRC reg */
 			snd_es1371_wait_src_ready(ensoniq);
 			outl(x, ES_REG(ensoniq, 1371_SMPRATE));
 			/* wait for WIP again */
-			for (t = 0; t < POLL_COUNT; t++)
+			for (t = 0; t < POLL_COUNT; t++) {
 				if (!(inl(ES_REG(ensoniq, 1371_CODEC)) & ES_1371_CODEC_WIP))
 					break;		
+				udelay(IO_DELAY);
+			}
 			/* now wait for the stinkin' data (RDY) */
 			for (t = 0; t < POLL_COUNT; t++) {
 				if ((x = inl(ES_REG(ensoniq, 1371_CODEC))) & ES_1371_CODEC_RDY) {
@@ -242,14 +254,14 @@ static unsigned short snd_es1371_codec_read(void *private_data,
 			}
 			spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
 			if (++fail > 10) {
-				snd_printk("es1371: codec read timeout (final) at 0x%x, reg = 0x%x [0x%x]\n", ES_REG(ensoniq, 1371_CODEC), reg, inl(ES_REG(ensoniq, 1371_CODEC)));
+				snd_printk("es1371: codec read timeout (final) at 0x%lx, reg = 0x%x [0x%x]\n", ES_REG(ensoniq, 1371_CODEC), reg, inl(ES_REG(ensoniq, 1371_CODEC)));
 				return 0;
 			}
 			goto __again;
 		}
 		spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
 	}
-	snd_printk("es1371: codec read timeout at 0x%x [0x%x]\n", ES_REG(ensoniq, 1371_CODEC), inl(ES_REG(ensoniq, 1371_CODEC)));
+	snd_printk("es1371: codec read timeout at 0x%lx [0x%x]\n", ES_REG(ensoniq, 1371_CODEC), inl(ES_REG(ensoniq, 1371_CODEC)));
 	return 0;
 }
 
@@ -318,7 +330,7 @@ static unsigned int snd_es1371_dac1_rate(ensoniq_t * ensoniq,
 		rate = 48000;
 	if (rate < 4000)
 		rate = 4000;
-	freq = ((rate << 15) + 15000) / 3000;
+	freq = ((rate << 15) + 1500) / 3000;
 	result = ((freq * 3000) + (1 << 14)) >> 15;
 	if (set) {
 		r = (snd_es1371_wait_src_ready(ensoniq) & (ES_1371_SRC_DISABLE | ES_1371_DIS_P2 | ES_1371_DIS_R1)) | ES_1371_DIS_P1;
@@ -1374,8 +1386,8 @@ int snd_ensoniq_create(snd_card_t * card,
 	}
 	pci_set_master(pci);
 	pci_read_config_byte(pci, PCI_LATENCY_TIMER, &cmdb);
-	if (cmdb < 32)
-		cmdb = 32;
+	if (cmdb < 64)
+		cmdb = 64;
 	pci_write_config_byte(pci, PCI_LATENCY_TIMER, cmdb);
 	pci_read_config_byte(pci, PCI_REVISION_ID, &cmdb);
 	ensoniq->rev = cmdb;
@@ -1401,8 +1413,10 @@ int snd_ensoniq_create(snd_card_t * card,
 	ensoniq->ctrl = 0;
 	ensoniq->sctrl = 0;
 	ensoniq->cssr = 0;
-	if (ensoniq->subsystem_vendor_id == 0x107b &&
-	    ensoniq->subsystem_device_id == 0x2150)	/* Gateway Solo 2150 */
+	if ((ensoniq->subsystem_vendor_id == 0x107b &&
+	     ensoniq->subsystem_device_id == 0x2150) ||	/* Gateway Solo 2150 */
+	    (ensoniq->subsystem_vendor_id == 0x13bd &&
+	     ensoniq->subsystem_device_id == 0x100c))   /* EV1938 on Mebius PC-MJ100V */
 		ensoniq->ctrl |= ES_1371_GPIO_OUT(1);	/* turn amplifier on */
 	/* initialize the chips */
 	outl(ensoniq->ctrl, ES_REG(ensoniq, CONTROL));
