@@ -331,7 +331,7 @@ void snd_fm801_interrupt(fm801_t *codec, unsigned short status)
 	if ((status & (FM801_IRQ_PLAYBACK | FM801_IRQ_CAPTURE)) == 0)
 		return;
 	if (codec->pcm && (status & FM801_IRQ_PLAYBACK)) {
-		spin_lock_irq(&codec->reg_lock);
+		spin_lock(&codec->reg_lock);
 		codec->ply_buf++;
 		codec->ply_pos += codec->ply_count;
 		codec->ply_pos %= codec->ply_size;
@@ -341,11 +341,11 @@ void snd_fm801_interrupt(fm801_t *codec, unsigned short status)
 				(codec->ply_buf & 1) ?
 					FM801_REG(codec, PLY_BUF1) :
 					FM801_REG(codec, PLY_BUF2));
-		spin_unlock_irq(&codec->reg_lock);
+		spin_unlock(&codec->reg_lock);
 		snd_pcm_transfer_done(codec->playback_subchn);
 	}
 	if (codec->pcm && (status & FM801_IRQ_CAPTURE)) {
-		spin_lock_irq(&codec->reg_lock);
+		spin_lock(&codec->reg_lock);
 		codec->cap_buf++;
 		codec->cap_pos += codec->cap_count;
 		codec->cap_pos %= codec->cap_size;
@@ -355,7 +355,7 @@ void snd_fm801_interrupt(fm801_t *codec, unsigned short status)
 				(codec->cap_buf & 1) ?
 					FM801_REG(codec, PLY_BUF1) :
 					FM801_REG(codec, PLY_BUF2));
-		spin_unlock_irq(&codec->reg_lock);
+		spin_unlock(&codec->reg_lock);
 		snd_pcm_transfer_done(codec->capture_subchn);
 	}
 	/* clear interrupt */
