@@ -1739,25 +1739,17 @@ int snd_sonicvibes_create(snd_card_t * card,
 	sonic = snd_magic_kcalloc(sonicvibes_t, 0, GFP_KERNEL);
 	if (sonic == NULL)
 		return -ENOMEM;
-	sonic->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&sonic->reg_lock);
 	sonic->card = card;
 	sonic->pci = pci;
 	sonic->dma1ptr = dma1ptr;
 	sonic->dma2ptr = dma2ptr;
 	sonic->irqptr = irqptr;
-#ifdef NEW_PCI
-	sonic->sb_port = pci->resource[0].start;
-	sonic->enh_port = pci->resource[1].start;
-	sonic->synth_port = pci->resource[2].start;
-	sonic->midi_port = pci->resource[3].start;
-	sonic->game_port = pci->resource[4].start;
-#else
-	sonic->sb_port = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-	sonic->enh_port = pci->base_address[1] & ~PCI_BASE_ADDRESS_SPACE;
-	sonic->synth_port = pci->base_address[2] & ~PCI_BASE_ADDRESS_SPACE;
-	sonic->midi_port = pci->base_address[3] & ~PCI_BASE_ADDRESS_SPACE;
-	sonic->game_port = pci->base_address[4] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	sonic->sb_port = pci_resource_start(pci, 0);
+	sonic->enh_port = pci_resource_start(pci, 1);
+	sonic->synth_port = pci_resource_start(pci, 2);
+	sonic->midi_port = pci_resource_start(pci, 3);
+	sonic->game_port = pci_resource_start(pci, 4);
 	pci_read_config_word(pci, PCI_COMMAND, &cmdw);
 	if (!(cmdw & PCI_COMMAND_IO)) {
 		cmdw |= PCI_COMMAND_IO;
@@ -2005,15 +1997,14 @@ EXPORT_SYMBOL(snd_sonicvibes_midi);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_s3_86c617_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_s3_86c617_exit(void)
 {
 }
 
-#endif
+module_init(alsa_s3_86c617_init)
+module_exit(alsa_s3_86c617_exit)
