@@ -2764,8 +2764,7 @@ int snd_trident_create(snd_card_t * card,
 		pci_write_config_word(pci, PCI_COMMAND, cmdw);
 	}
 	pci_set_master(pci);
-	pci_read_config_dword(pci, 0x10, &trident->port);
-	trident->port &= ~0x0f;
+	trident->port = pci_resource_start(pci, 0);
 
 	/* initialize chip */
 
@@ -2870,7 +2869,7 @@ void snd_trident_interrupt(trident_t * trident)
 			unsigned int old = trident->ChRegs->lpChAint[x];
 			unsigned int old1 = trident->ChRegs->lpChAint[x^1];
 			if (old & dwMask) {
-				spin_lock_irq(&trident->reg_lock);
+				spin_lock(&trident->reg_lock);
 				if (trident->synth.voices[channel].pcm) {
 					/* pcm interrupt */
 					tpcm = &trident->synth.voices[channel];
@@ -2883,9 +2882,9 @@ void snd_trident_interrupt(trident_t * trident)
 							else
 								temp = inl(TRID_REG(trident,T4D_CSPF_A ));
 							if (!(temp & dwMask)) {
-								spin_unlock_irq(&trident->reg_lock);
+								spin_unlock(&trident->reg_lock);
 								snd_pcm_transfer_done(tpcm->subchn);
-								spin_lock_irq(&trident->reg_lock);
+								spin_lock(&trident->reg_lock);
 							}
 						} else {
 							if (trident->device == TRIDENT_DEVICE_ID_NX)
@@ -2908,9 +2907,9 @@ void snd_trident_interrupt(trident_t * trident)
 								} else {
 									outw((eso & 0xffff), TRID_REG(trident, CH_DX_ESO_DELTA + 2));
 								}
-								spin_unlock_irq(&trident->reg_lock);
+								spin_unlock(&trident->reg_lock);
 								snd_pcm_transfer_done(tpcm->subchn);
-								spin_lock_irq(&trident->reg_lock);
+								spin_lock(&trident->reg_lock);
 							}
 						}
 					} else {
@@ -2926,7 +2925,7 @@ void snd_trident_interrupt(trident_t * trident)
 					snd_trident_stop_voice(trident, channel);
 					snd_trident_disable_voice_irq(trident, channel);
 				}
-				spin_unlock_irq(&trident->reg_lock);
+				spin_unlock(&trident->reg_lock);
 				trident->ChRegs->lpChAint[x] = dwMask;
 				trident->ChRegs->lpChAint[x^1] = 0;
 				IWriteAint(trident->ChRegs);
