@@ -43,32 +43,32 @@ static int snd_ymfpci_free(ymfpci_t * codec);
 
 static inline u8 snd_ymfpci_readb(ymfpci_t *codec, u32 offset)
 {
-	return *((volatile u8 *)(codec->reg_area_virt + offset));
+	return readb(codec->reg_area_virt + offset);
 }
 
 static inline void snd_ymfpci_writeb(ymfpci_t *codec, u32 offset, u8 val)
 {
-	*((volatile u8 *)(codec->reg_area_virt + offset)) = val;
+	writeb(val, codec->reg_area_virt + offset);
 }
 
 static inline u16 snd_ymfpci_readw(ymfpci_t *codec, u32 offset)
 {
-	return *((volatile u16 *)(codec->reg_area_virt + offset));
+	return readw(codec->reg_area_virt + offset);
 }
 
 static inline void snd_ymfpci_writew(ymfpci_t *codec, u32 offset, u16 val)
 {
-	*((volatile u16 *)(codec->reg_area_virt + offset)) = val;
+	writew(val, codec->reg_area_virt + offset);
 }
 
 static inline u32 snd_ymfpci_readl(ymfpci_t *codec, u32 offset)
 {
-	return *((volatile u32 *)(codec->reg_area_virt + offset));
+	return readl(codec->reg_area_virt + offset);
 }
 
 static inline void snd_ymfpci_writel(ymfpci_t *codec, u32 offset, u32 val)
 {
-	*((volatile u32 *)(codec->reg_area_virt + offset)) = val;
+	writel(val, codec->reg_area_virt + offset);
 }
 
 static int snd_ymfpci_codec_ready(ymfpci_t *codec, int secondary, int sched)
@@ -344,26 +344,25 @@ static int snd_ymfpci_playback_ioctl(void *private_data,
 {
 	snd_pcm_runtime_t *runtime = substream->runtime;
 	int result;
-	u32 tmp;
 
 	result = snd_pcm_lib_ioctl(private_data, substream, cmd, arg);
 	if (result < 0)
 		return result;		
-#if 0
 	if (cmd == SND_PCM_IOCTL1_PARAMS) {
-		tmp = (u32)runtime->format.rate << 16;
-		tmp /= 48000;
-		tmp >>= 8;
-		if (snd_pcm_format_width(runtime->format.format) == 16)
-			tmp <<= 1;
-		if (runtime->format.voices == 2)
-			tmp <<= 1;
-		runtime->frag_size = tmp;
-		runtime->bytes_align = tmp;
-		runtime->frags = runtime->buffer_size / runtime->frag_size;
-		runtime->buffer_size = runtime->frags * runtime->frag_size;
+		if (runtime->mode == SND_PCM_MODE_BLOCK) {
+			u32 tmp;
+			tmp = (u32)runtime->format.rate << 16;
+			tmp /= 48000;
+			tmp >>= 8;
+			if (snd_pcm_format_width(runtime->format.format) == 16)
+				tmp <<= 1;
+			if (runtime->format.voices == 2)
+				tmp <<= 1;
+			runtime->frags = snd_pcm_lib_transfer_size(substream) / tmp;
+			runtime->buf.block.frag_size = tmp;
+			snd_pcm_lib_set_buffer_size(substream, runtime->frags * runtime->buf.block.frag_size);
+		}
 	}
-#endif
 	return result;
 }
 
@@ -374,22 +373,25 @@ static int snd_ymfpci_capture_ioctl(void *private_data,
 {
 	snd_pcm_runtime_t *runtime = substream->runtime;
 	int result;
-	u32 tmp;
 
 	result = snd_pcm_lib_ioctl(private_data, substream, cmd, arg);
 	if (result < 0)
 		return result;		
-#if 0
 	if (cmd == SND_PCM_IOCTL1_PARAMS) {
-		tmp = (u32)runtime->format.rate << 16;
-		tmp /= 48000;
-		tmp >>= 8;
-		runtime->frag_size = tmp;
-		runtime->bytes_align = tmp;
-		runtime->frags = runtime->buffer_size / runtime->frag_size;
-		runtime->buffer_size = runtime->frags * runtime->frag_size;
+		if (runtime->mode == SND_PCM_MODE_BLOCK) {
+			u32 tmp;
+			tmp = (u32)runtime->format.rate << 16;
+			tmp /= 48000;
+			tmp >>= 8;
+			if (snd_pcm_format_width(runtime->format.format) == 16)
+				tmp <<= 1;
+			if (runtime->format.voices == 2)
+				tmp <<= 1;
+			runtime->frags = snd_pcm_lib_transfer_size(substream) / tmp;
+			runtime->buf.block.frag_size = tmp;
+			snd_pcm_lib_set_buffer_size(substream, runtime->frags * runtime->buf.block.frag_size);
+		}
 	}
-#endif
 	return result;
 }
 
@@ -544,19 +546,19 @@ static void snd_ymfpci_pcm_init_voice(ymfpci_voice_t *voice, int stereo,
 		} else {
 			if (!spdif) {
 				if ((voice->number & 1) == 0) {
-					bank->format |= 1;
 					bank->left_gain =
 					bank->left_gain_end = 0x40000000;
 				} else {
+					bank->format |= 1;
 					bank->right_gain =
 					bank->right_gain_end = 0x40000000;
 				}
 			} else {
 				if ((voice->number & 1) == 0) {
-					bank->format |= 1;
 					bank->eff2_gain =
 					bank->eff2_gain_end = 0x40000000;
 				} else {
+					bank->format |= 1;
 					bank->eff3_gain =
 					bank->eff3_gain_end = 0x40000000;
 				}
@@ -725,7 +727,7 @@ static snd_pcm_hardware_t snd_ymfpci_playback =
 	min_voices:		1,
 	max_voices:		2,
 	min_fragment_size:	32,
-	max_fragment_size:	256,
+	max_fragment_size:	256 * 1024, /* XXX */
 	fragment_align:		1,
 	fifo_size:		0,
 	transfer_block_size:	4,
@@ -750,7 +752,7 @@ static snd_pcm_hardware_t snd_ymfpci_capture =
 	min_voices:		1,
 	max_voices:		2,
 	min_fragment_size:	32,
-	max_fragment_size:	256,
+	max_fragment_size:	256 * 1024, /* XXX */
 	fragment_align:		1,
 	fifo_size:		0,
 	transfer_block_size:	4,
