@@ -2,7 +2,7 @@
  *  synth callback routines for the emu8000 (AWE32/64)
  *
  *  Copyright (C) 1999 Steve Ratcliffe
- *  Copyright (C) 1999-2000 Takashi Iwai <iwai@ww.uni-erlangen.de>
+ *  Copyright (C) 1999-2000 Takashi Iwai <tiwai@suse.de>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -232,14 +232,12 @@ start_voice(snd_emux_voice_t *vp)
 	unsigned int temp;
 	int ch;
 	int addr;
-	soundfont_voice_parm_block_t *parm;
 	snd_midi_channel_t *chan;
 	emu8000_t *hw;
 
 	hw = snd_magic_cast(emu8000_t, vp->hw,);
 	ch = vp->ch;
 	chan = vp->chan;
-	parm = (soundfont_voice_parm_block_t*)&vp->reg.parm;
 
 	/* channel to be silent and idle */
 	EMU8000_DCYSUSV_WRITE(hw, ch, 0x0080);
