@@ -426,8 +426,8 @@ static int snd_sb16mixer_3d_stereo_enh_detect(sbmixer_t * sbmix)
 	test1 = oreg ^ 1;
 	snd_sb16mixer_write(sbmix, SB_DSP4_3DSE, test1);
 	test2 = snd_sb16mixer_read(sbmix, SB_DSP4_3DSE);
-	if (test1 == test2) {
-		/* found */
+	if (~(test1 ^ test2) & 0x01) {
+		/* LSB bits are equal, 3DSE found */
 		snd_sb16mixer_write(sbmix, SB_DSP4_3DSE, oreg);
 		result++;
 	}
